      implicit none
#include "Zmedia.h"
#include "Zmass.h"
c
c          test compton
c 
      record /epmedia/media
      integer i, io, imax
      real*8 Ee, prob, Eg, cosg, cose, Egp, path
      character*20 file

      io = 10
      imax = 50000
      call cerrorMsg('compton sampling test', 1)
      call cerrorMsg(
     * " prob/r.l  Eg'  Ee   cosg  cose  sampled_path", 1)


      call  cerrorMsg(
     * "Enter gamma energy, events(50000) and file path"//
     * "('../../Data/BaseM/BGO')",  1)
      file = '../../Data/BaseM/BGO'
      read(*, *) Eg, imax, file
      call cerrorMsg(file,  1)

      open(io, file=file, action='read')
      call epReadMTbl(io, media)
      close(io)
      call epGetEffZA(media)
      write(*,*) '# "compton test"'
      write(*,*) 
     * '# "prob/r.l"    "Eg_out"  "Ee"   "cosg"  "cose"  "path"'
      do i = 1,  imax
         call epcompp(media, Eg, prob, path)
         call epcompea(Eg, Egp, Ee, cosg, cose)
         write(*,*) sngl(prob), sngl(Egp),
     *     sngl(Ee), sngl(cosg), sngl(cose), sngl(path)
      enddo
      end
